@@ -86,6 +86,12 @@ class RequestToInstallPluginSignal(Signal):
         super().dispatch(path)
 
 
+@singleton
+class InstallPluginFinishSignal(Signal):
+    def dispatch(self, plugin: IPlugin):
+        super().dispatch()
+
+
 @singleton
 class PluginInfoUpdateSignal(Signal):
     """
